==================
Useful Links Index
==================

AmeriFlux
---------

- `Levels of data processing <https://ameriflux.lbl.gov/data/aboutdata/data-processing-levels/>`_
- `AmeriFlux data pipeline <https://ameriflux.lbl.gov/data/data-processing-pipelines/>`_

Useful Libraries (R and Python)
-------------------------------

Data Prep and Processing
~~~~~~~~~~~~~~~~~~~~~~~~

- `atmos <https://github.com/atmos-python/atmos>`_ - An atmospheric sciences library for Python
- `EddyCleanR <https://github.com/adamhsparks/EddyCleanR>`_ - Fills gaps and removes outliers in eddy covariance data.
- `PyFluxPro <https://github.com/OzFlux/PyFluxPro3.2>`_ - Quality control, gap filling and partitioning of flux tower data.
- `REddyProc <https://github.com/bgctw/REddyProc>`_ - Processing data from micrometeorological Eddy-Covariance systems
- `EddyCovarianceProcessing <https://github.com/June-Spaceboots/EddyCovarianceProcessing>`_ - Code for processing Eddy Covariance
- `flux_capacitor <https://github.com/UofM-CEOS/flux_capacitor>`_ - Tools for processing flux data (eddy covariance).
- `EasyFlux-DL-CR3000 <https://github.com/wsular/EasyFlux-DL-CR3000>`_ - CR3000 datalogger program for Campbell eddy-covariance systems
- `flux-data-qaqc <https://github.com/Open-ET/flux-data-qaqc>`_ - Energy Balance Closure Analysis and Eddy Flux Post-Processing
- `eddypro-gui <https://github.com/LI-COR/eddypro-gui>`_ - Software for processing eddy covariance data
- `openeddy <https://github.com/lsigut/openeddy>`_ - R package for low-frequency eddy covariance data processing
- `ONEFlux <https://github.com/FLUXNET/ONEFlux>`_ - Open Network-Enabled Flux processing pipeline

Partitioning Fluxes
~~~~~~~~~~~~~~~~~~~

- `fluxpart <https://github.com/usda-ars-ussl/fluxpart>`_ - Python module for partitioning eddy covariance fluxes
- `ecosystem-transpiration <https://github.com/jnelson18/ecosystem-transpiration>`_ - Estimate transpiration from eddy covariance

Remote Sensing Estimates
~~~~~~~~~~~~~~~~~~~~~~~~

- `METRIC <https://github.com/NASA-DEVELOP/METRIC>`_ - Estimate daily evapotranspiration from Landsat
- `pyTSEB <https://github.com/kratzert/pyTSEB>`_ - Two-Source Energy Balance model for ET
- `openet-ssebop-beta <https://github.com/spizwhiz/openet-ssebop-beta>`_ - Earth Engine SSEBop ET Model
- `openet-core-beta <https://github.com/pblankenau2/openet-core-beta>`_ - OpenET Core Components
- `pymicra <https://github.com/tomchor/pymicra>`_ - A Python tool for micrometeorological analysis

Miscellaneous
~~~~~~~~~~~~~

- `Planetary_boundary_height_for_FFP <https://github.com/sunxm19/Planetary_boundary_height_for_FFP>`_ - Extracting boundary layer height from NOAA data
- `amerifluxr <https://github.com/chuhousen/amerifluxr>`_ - R interface for AmeriFlux data and metadata
- `Open-ET <https://github.com/Open-ET>`_ - Open-ET packages
- `atmos-python/atmos <https://github.com/atmos-python/atmos>`_ - Atmospheric sciences library for Python

Reference ET
~~~~~~~~~~~~

- `PyETo <https://github.com/woodcrafty/PyETo>`_ - Python package for calculating reference evapotranspiration
- `RefET-GEE <https://github.com/cgmorton/RefET-GEE>`_ - ASCE Reference ET Functions for Google Earth Engine
- `et-demands <https://github.com/usbr/et-demands>`_ - Dual crop coefficient crop water demand model
- `openet-refet-gee <https://github.com/Open-ET/openet-refet-gee>`_ - ASCE Reference ET Functions for GEE
